constrainttools.AbsoluteIndexConstraint
=======================================

.. inheritance-diagram:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint
   :private-bases:

.. autoclass:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.indices

   .. note:: Inherited from :py:class:`constrainttools._AbsoluteConstraint <abjad.tools.constrainttools._AbsoluteConstraint._AbsoluteConstraint._AbsoluteConstraint>`

.. autoattribute:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.kind

   .. note:: Inherited from :py:class:`constrainttools._Constraint <abjad.tools.constrainttools._Constraint._Constraint._Constraint>`

.. autoattribute:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.max_index

   .. note:: Inherited from :py:class:`constrainttools._AbsoluteConstraint <abjad.tools.constrainttools._AbsoluteConstraint._AbsoluteConstraint._AbsoluteConstraint>`

.. autoattribute:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.predicate

   .. note:: Inherited from :py:class:`constrainttools._Constraint <abjad.tools.constrainttools._Constraint._Constraint._Constraint>`

Special Methods
---------------

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__call__

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__repr__

   .. note:: Inherited from :py:class:`constrainttools._Constraint <abjad.tools.constrainttools._Constraint._Constraint._Constraint>`

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.constrainttools.AbsoluteIndexConstraint.AbsoluteIndexConstraint.AbsoluteIndexConstraint.__str__

   .. note:: Inherited from `__builtin__.object`
